@@ -52,6 +52,14 @@ def test_h3fy_clip():
         sac_hex.area.sum(), 13131736346.537422, decimal=0
     )
 
+def test_h3fy_clip_buffer():
+    sac1 = load_example("Sacramento1")
+    sac1 = geopandas.read_file(sac1.get_path("sacramentot2.shp"))
+    sac_hex = h3fy(sac1, clip=True, buffer=True)
+    sac_hex = sac_hex.to_crs(sac_hex.estimate_utm_crs())
+    assert_almost_equal(
+        sac_hex.area.sum(), 13749446323.1722, decimal=0
+    )
 
 @pytest.mark.skipif(platform.system() == "Windows", reason='Unknown precision error on Windows. See #174 for details')
 def test_h3_multipoly():
